@@ -7,7 +7,7 @@ from IutyLib.commonutil.config import JConfig
 import os
 os.environ["TF_CPP_MIN_LOG_LEVEL"]='3'
 import tensorflow as tf
-from PIL import Image
+from PIL import Image,ImageStat,ImageEnhance
 import numpy as np
 
 import random
@@ -28,6 +28,11 @@ tfconfig.gpu_options.per_process_gpu_memory_fraction = 1
 tfconfig.gpu_options.allow_growth = True
 session = InteractiveSession(config=tfconfig)
 
+def getImageBright(img):
+    im = img.convert('L')
+    stat = ImageStat.Stat(im)
+    return stat.mean[0]
+
 def readBmp(files,imgw=None,imgh=None,imgf=None):
     
     if not imgw:
@@ -42,6 +47,11 @@ def readBmp(files,imgw=None,imgh=None,imgf=None):
     for file in files:
         img = Image.open(file)
         img = img.resize([imgw,imgh])
+        
+        lv = getImageBright(img)
+        evalue = 100.0/lv
+        img = ImageEnhance.Brightness(img).enhance(evalue)
+        
         img = np.array(img)
         
         #print(img[0][0][0])
