@@ -8,7 +8,7 @@ os.environ["TF_CPP_MIN_LOG_LEVEL"]='3'
 import tensorflow as tf
 from tensorflow.keras import Model
 from tensorflow.keras.layers import Layer
-from PIL import Image
+from PIL import Image,ImageStat,ImageEnhance
 import numpy as np
 
 import random
@@ -33,7 +33,10 @@ tfconfig.gpu_options.allow_growth = True
 session = InteractiveSession(config=tfconfig)
 
 
-
+def getImageBright(img):
+    im = img.convert('L')
+    stat = ImageStat.Stat(im)
+    return stat.mean[0]
 
 
 def readBmp(files,imgw=None,imgh=None,imgf=None):
@@ -50,6 +53,11 @@ def readBmp(files,imgw=None,imgh=None,imgf=None):
     for file in files:
         img = Image.open(file)
         img = img.resize([imgw,imgh])
+        
+        lv = getImageBright(img)
+        evalue = 100.0/lv
+        img = ImageEnhance.Brightness(img).enhance(evalue)
+        
         img = np.array(img)
         #print(img[0][0][0])
         img = img / 255.
